*******************************************************************************************************
* Program name: DANE_3_DPH_SD.do
* Program purpose: This program simulates impact of various VAT rates and excise duties on households and government revenues in the Czech Republic
* Program created:   June 2011 - January 2014, by Petr Jansky as a part of the TACR OMEGA project and in cooperation with the IFS
*******************************************************************************************************
*************************************************
****** VAT and Excise duty impact estimates *****
*************************************************
clear all
set more off
**************************** Basic set-up
* Folders, beginning of the STATA programme
global folder "D:\LTaxes\QUAIDS_MF\"

global outputs "$folder\Vysledky"
global inputs "$folder\Vstupy"
global confidence "$folder\outputs\131006_confidence"
cd "$folder\Vysledky"
global dec "prij_decil_oecd" // Deciles: type of income/expenditure decile/quintile: prij_kvantil_oecd, prij_decil_oecd, vyd_kvantil_oecd, vyd_decil_oecd
global QUAIDS "on" // whether to use QUAIDS elasticities or not (on/off)
global cversion "ed1"

capture program drop vat_impact
program define vat_impact

* Starting with the data
use "$inputs/131111_parameters_elasticities_2.dta" // the same, but with elasticities, as "$outputs/initial_estimates4.dta" // I copied and renamed parameters_elasticities_2 to be pec_0
set more off
	*ONLY for 2011:
	keep if year == 2011
	* Monthly expenditures - as well as everything else on a monthly basis
	gen expm = exp / pmes

* New set up of expendiutre groups and a new VAT rate - including the new expenditure groups (9-15) for a new VAT rate - external do file
do $folder/$skupiny

gen zero = 0
egen xxw_1 = rowtotal($xg_1)
egen xxw_2 = rowtotal($xg_2)
egen xxw_3 = rowtotal($xg_3)
egen xxw_4 = rowtotal($xg_4)
egen xxw_5 = rowtotal($xg_5)
egen xxw_6 = rowtotal($xg_6)
egen xxw_7 = rowtotal($xg_7)
egen xxw_8 = rowtotal($xg_8)
egen xxw_9 = rowtotal(zero $xg_9)
egen xxw_10 = rowtotal(zero $xg_10)
egen xxw_11 = rowtotal(zero $xg_11)
egen xxw_12 = rowtotal(zero $xg_12)
egen xxw_13 = rowtotal(zero $xg_13)
egen xxw_14 = rowtotal(zero $xg_14)
egen xxw_15 = rowtotal(zero $xg_15)
egen xwx = rowtotal(xxw_1 xxw_2 xxw_3 xxw_4 xxw_5 xxw_6 xxw_7 xxw_8 xxw_9 xxw_10 xxw_11 xxw_12 xxw_13 xxw_14 xxw_15)

foreach g in  9 10 11 12 13 14 15 {
gen w`g' = 0 // it does not exist in the data until now
}

foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 {
* Group related variables - shares w
gen xw_`g' = xxw_`g' / xwx
replace xw_`g' = 0 if xw_`g' == .
}
* Now I have redefined and recomputed the expenditure shares w1-w8 as xw_1-8
* Replace the original shares with the newly defined shares
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 {
gen original_w`g' = w`g'
replace w`g' = xw_`g'
}

*clear all
*set more off
foreach r of numlist 0(1)0 { // 1300 - the number of bootstrapped estimates // zero is the version presented (I want to run this from 0 to 1300 and then use the last row - 0 - separately in the bstat computation below) - foreach r of numlist 0(1)1300 
*clear all
*use "$confidence\pec_`r'.dta"
*clear all
	* choose your favourite elasticity - hicksian_3_ or marshall_3_
	global elast "marshall_3_" 
	* Growth of the real income - set at the 5 parameter value
	gen growth_income = `5'

	
******************************************************
****** Set-up for excise duties: Fuel, Alco, Tob *****
******************************************************

** Fuel variables
* Expenditures on fuel
egen e_fuel = rowtotal(exp3640)
replace e_fuel = e_fuel / pmes
* Share of expenditures on fuel in the relevant expenditure's group
gen e_fuel_w6 = e_fuel / (w6 * expm) 
replace e_fuel_w6 = 0 if w6 == 0
* Price of fuel - assuming weighted average price of 34.485125
gen p_fuel = 34.485125
* Amount of fuel - assuming weighted average price of 34.485125
gen a_fuel = e_fuel / p_fuel	
* Excise duty paid - Fuel
gen ed_fuel = a_fuel * `20' // 12.30 // I assume that all expenditures on either petrol or diesel and a weighted average excise duty of 12.30 CZK per litre.

** Beer variables
* Expenditures on beer
egen e_beer = rowtotal(exp2830 exp2931 exp2932)
replace e_beer = e_beer / pmes
* Share of expenditures on beer in the relevant expenditure's group
gen e_beer_w2 = e_beer / (w2 * expm) 
* Amount of beer
egen a_beer = rowtotal(amount2830 amount2931 amount2932)
replace a_beer = a_beer / pmes
* Price of beer per litre: unit value price for beer - across beer, but individual for each household
gen p_beer = e_beer / a_beer
* Excise duty paid - beer
gen ed_beer = a_beer * `21' // 3.2

** Wine variables
* Expenditures on wine
egen e_wine = rowtotal(exp2841 exp2842 exp2941 exp2942)
replace e_wine = e_wine / pmes
* Share of expenditures on wine in the relevant expenditure's group
gen e_wine_w2 = e_wine / (w2 * expm) 
gen e_wine_expm_100 = e_wine / expm * 100
* Amount of wine
egen a_wine = rowtotal(amount2841 amount2842 amount2941 amount2942)
replace a_wine = a_wine / pmes
* Price of wine per litre: unit value price for wine - across wines, but individual for each household
gen p_wine = e_wine / a_wine
* Excise duty paid - wine
gen ed_wine = a_wine * `22'

** Sprit variables
* Expenditures on spirit
egen e_spirit = rowtotal(exp2850 exp2951 exp2952)
replace e_spirit = e_spirit / pmes
* Share of expenditures on spirit in the relevant expenditure's group
gen e_spirit_w2 = e_spirit / (w2 * expm) 
* Amount of spirit
egen a_spirit = rowtotal(amount2850 amount2951 amount2952)
replace a_spirit = a_spirit / pmes
* Price of spirit per litre: unit value price for spirit - across spirit, but individual for each household
gen p_spirit = e_spirit / a_spirit
* Excise duty paid - spirit
gen ed_spirit = a_spirit * `23' // 57

** Tobacco variables
* Expenditures on tobacco - cigarettes, cigar and other tobacco
* Cigarettes only
egen e_cig =  rowtotal(exp3901)
replace e_cig = e_cig / pmes
* cigar
egen e_cigar =  rowtotal(exp3902)
replace e_cigar = e_cigar / pmes
* Other tobacco
egen e_otob =  rowtotal(exp3903)
replace e_otob = e_otob / pmes
* Share of cigarettes / and other tobacco in the relevant expenditure's group
gen e_cig_w2 = e_cig / (w2 * expm) 
gen e_cigar_w2 = e_cigar / (w2 * expm) 
gen e_otob_w2 = e_otob / (w2 * expm) 
* Price of tobacco - assuming weighted average price of 69.72 CZK per cigarette pack of 20
* v esku v roce 2012 je promerna cena 3486 CZK za 1 000 cigaret. Prmrn cena krabiky cigaret (20 ks) je tak 69.72 CZK.
* http://ec.europa.eu/taxation_customs/resources/documents/taxation/excise_duties/tobacco_products/rates/excise_duties-part_iii_tobacco_en.pdf
gen p_cig = 69.72 / 20 // cena za cigaretu - tedy vydelena cena za krabicku 20-ti
* Price per piece - Odhad na zklade cen v obchodech
gen p_cigar = 30 // za jeden doutnik
* Price per kilogram - Odhad na zklade cen v obchodech - 120 Kc 40 gramu = 3000 Kc za kilo
gen p_otob = 3000
* Amount of cigarettes / other tobacco (e_ already in monthly values)
gen a_cig = e_cig / p_cig
gen a_cigar = e_cigar / p_cigar
gen a_otob = e_otob / p_otob
* Excise duty paid - tobacco
gen ed_cig = a_cig * `24' // 2.1
gen ed_cigar = a_cigar * `25' // 1.25
gen ed_otob = a_otob * `26' // 1400


* Total excise duty paid - across all excises for each household
egen ed = rowtotal(ed_fuel ed_beer ed_wine ed_spirit ed_cig ed_cigar ed_otob)
egen ed_alco = rowtotal(ed_beer ed_wine ed_spirit)
egen ed_tob = rowtotal(ed_cig ed_cigar ed_otob)

* Excise duty paid per expenditure for each household: excise duty paid divdided by the expenditure *100 to make it percentage
gen ed_expm = ed / expm * 100
foreach edg in fuel beer wine spirit alco cig cigar otob tob { 
gen ed_expm_`edg' = ed_`edg' / expm  * 100
gen ed_moninc_`edg' = ed_`edg' / moninc  * 100
} 

* Average excise duty paid per quantity for each household: excise duty paid divdided by the amounts
foreach edg in fuel beer wine spirit cig cigar otob { 
gen eda_`edg' = ed_`edg' / a_`edg'
replace eda_`edg' = 0 if eda_`edg' == .
}

**************************************************************************************************
****** Simulation of changes in prices due to changes in VAT rates or Excise duties **************
**************************************************************************************************


* Time: 0 - data/2011 (10 and 20 VAT rates), 1 - now/2012 (14 and 20 VAT rates), 2 - 2013
* Variables: E - nominal expenditures, Q - real expenditures, P - price levels
foreach g in 1 2 3 4 5 6 7 8 9  10 11 12 13 14 15 { 
	* Price indices 
	* Prince index for 2011 - the data with VAT rates 10 and 20%
	gen p_t0_w`g' = (100 + `31') / 100
	replace p_t0_w`g' = (100 + `30') / 100 if `g' == 1 | `g' == 5
	replace p_t0_w`g' = (100 + `32') / 100 if `g' == 9	|  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15 // the third VAT rate
	* Prince index for 2012 - with VAT rates 14 and 20%
	gen p_t1_w`g' = (100 + `2') / 100
	replace p_t1_w`g' = (100 + `1') / 100 if `g' == 1 | `g' == 5
	replace p_t1_w`g' = (100 + `28') / 100 if `g' == 9	|  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	* Prince index for 2013 - the data with VAT rates depending on the parameters (e.g. 15 and 21)
	gen p_t2_w`g' = (100 + `4') / (100) 
	replace p_t2_w`g' = (100 + `3') / 100 if `g' == 1 | `g' == 5
	replace p_t2_w`g' = (100 + `29') / 100 if `g' == 9	|  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
* I compute the components by which the price index - p_t2_w`g' - should increase and then I add these together to the price index, p_t2_w`g'
* Specific change - what if the existing duty is increased by X CZK per unit?
	gen ded1_fuel_w`g' = `6' / (p_fuel) * (100 + `4') / 100 if `g' == 6
	replace ded1_fuel_w`g' = 0 if `6' == 0
	gen ded1_beer_w`g' = `7' / (p_beer) * (100 + `4') / 100 if `g' == 2
	replace ded1_beer_w`g' = 0 if `7' == 0
	gen ded1_wine_w`g' = `8' / (p_wine) * (100 + `4') / 100 if `g' == 2
	replace ded1_wine_w`g' = 0 if `8' == 0
	gen ded1_spirit_w`g' = `9' / (p_spirit) * (100 + `4') / 100 if `g' == 2
	replace ded1_spirit_w`g' = 0 if `9' == 0
	gen ded1_cig_w`g' = `10' / (p_cig) * (100 + `4') / 100 if `g' == 2
	replace ded1_cig_w`g' = 0 if `10' == 0
	gen ded1_cigar_w`g' = `11' / (p_cigar) * (100 + `4') / 100 if `g' == 2
	replace ded1_cigar_w`g' = 0 if `11' == 0
	gen ded1_otob_w`g' = `12' / (p_otob) * (100 + `4') / 100 if `g' == 2
	replace ded1_otob_w`g' = 0 if `12' == 0

* Percentage change	- what if the existing excise duty rates increase by X%?
	gen ded2_fuel_w`g' = eda_fuel / p_fuel * (`13') / 100 * (100 + `4') / 100  if `g' == 6
	replace ded2_fuel_w`g' = 0 if `13' == 0
	gen ded2_beer_w`g' = eda_beer / p_beer * (`14') / 100 * (100 + `4') / 100 if `g' == 2
	replace ded2_beer_w`g' = 0 if `14' == 0
	gen ded2_wine_w`g' = (eda_wine / p_wine) * (`15' / 100) * (100 + `4') / 100 if `g' == 2
	replace ded2_wine_w`g' = 0 if `15' == 0
	gen ded2_spirit_w`g' = eda_spirit / p_spirit * (`16') / 100 * (100 + `4') / 100  if `g' == 2
	replace ded2_spirit_w`g' = 0 if `16' == 0
	gen ded2_cig_w`g' = eda_cig / p_cig * (`17') / 100 * (100 + `4') / 100 if `g' == 2
	replace ded2_cig_w`g' = 0 if `17' == 0
	gen ded2_cigar_w`g' = eda_cigar / p_cigar * (`18') / 100 * (100 + `4') / 100 if `g' == 2
	replace ded2_cigar_w`g' = 0 if `18' == 0
	gen ded2_otob_w`g' = eda_otob / p_otob * (`19') / 100 * (100 + `4') / 100 if `g' == 2
	replace ded2_otob_w`g' = 0 if `19' == 0


* Summing up the impact on price indices from changes in excise duties
gen ded_w`g' = 0
replace ded_w`g' = ded_w`g' + ded1_fuel_w`g'  if ded1_fuel_w`g' != . & ded1_fuel_w`g' != 0
replace ded_w`g' = ded_w`g' + (ded2_fuel_w`g') if ded2_fuel_w`g' != . & ded2_fuel_w`g' != 0
* This is adding the impact from excise duty on fuel to impact from VAT
replace p_t2_w`g' = p_t2_w`g' + e_fuel_w6 * (ded_w`g') if `g' == 6
foreach edg in beer wine spirit cig cigar otob { 
replace ded_w`g' = ded_w`g' + ded1_`edg'_w`g'  if ded1_`edg'_w`g' != . & ded1_`edg'_w`g' != 0
replace ded_w`g' = ded_w`g' + (ded2_`edg'_w`g') if ded2_`edg'_w`g' != . & ded2_`edg'_w`g' != 0
* This is adding the impact from various excise duties to impact from VAT
replace p_t2_w`g' = p_t2_w`g' + e_`edg'_w2 * (ded_w`g') if `g' == 2 // p_t2_w2/1.21 = p_t2_w2/1.21 + e_wine_w2/0.06196 * ded_w2/0.1365
}

	* Change in Price indicies
	gen dpp_t01_w`g' = (p_t1_w`g' - p_t0_w`g') / p_t0_w`g'
	gen dpp_t02_w`g' = (p_t2_w`g' - p_t0_w`g') / p_t0_w`g'
	gen dpp_t12_w`g' = (p_t2_w`g' - p_t1_w`g') / p_t1_w`g'
	
	* Nominal expenditures
	gen e_t0_w`g' = expm * w`g'
	
	* Quantities = Nominal Exp / Price index
	gen q_t0_w`g' = e_t0_w`g' / p_t0_w`g'
}
 

	if "$QUAIDS" == "on" {
	* Elasticity for the new VAT rate expenditure groups - 9-15
	* assuming the new expenditure group has the same elasticity as of the group selected in the set-up (likely group 5)
	* assuming the sizes of elasticities are proportional to the relative size of the expenditure shares (e.g. if w9 is much smaller than w5, then it will have lower impact on other groups as well) and that is why it is multiplied by * (w`g'/w`gg')
	foreach g in 9 10 11 12 13 14 15  { // 1 2 3 4 5 6 7 8
	local gg = xz_`g'  // $xz_`g'
	foreach cisl in 1 2 3 4 5 6 7 8 { // 9 10 11 12 13 14 15 
	capture gen $elast`cisl'_`g' = $elast`cisl'_`gg'      
	capture gen $elast`g'_`cisl' = $elast`gg'_`cisl'      
	}
	capture gen IncElast_`g' = IncElast_`gg'      
	capture replace IncElast_`g' = IncElast_`gg'      
	capture gen IncElast_`g' = 0 if xz_`g' == 0
	capture replace IncElast_`g' = 0 if xz_`g' == 0
	capture gen $elast`g'_`g' = $elast`gg'_`gg' 
	}
	
	foreach g in 9 10 11 12 13 14 15  { // 1 2 3 4 5 6 7 8
	local gg = xz_`g'
	foreach cisl in 9 10 11 12 13 14 15  { // 
	capture gen $elast`cisl'_`g' = $elast`cisl'_`gg'      
	capture gen $elast`g'_`cisl' = $elast`gg'_`cisl'       
	}
	}

	* If there is no change in the new VAT rates, then zeros:
	foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15  { // 
	foreach cisl in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15  { // 
	capture gen $elast`cisl'_`g' = 0 if xz_`g' == 0
	capture gen $elast`g'_`cisl' = 0 if xz_`g' == 0
	capture replace $elast`cisl'_`g' = 0 if xz_`g' == 0
	capture replace $elast`g'_`cisl' = 0 if xz_`g' == 0
	}
	}
	
	gen w0 = 0
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
	* defining the weights
	local gg = xz_`g'  // $xz_`g'
	gen b`g' = 1 if `g'== `gg'
	replace b`g' = (w`g'/(w`gg'+w`g')) if `g'!= `gg'
	capture replace b`gg' = (w`gg'/(w`gg'+w`g')) if `g'!= `gg'
	replace b`g' = 0 if b`g'== .
	}


foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
	* Percentage changes in Quantities
	global elast "marshall_3_" 
	* Adjusting the elasticities
	foreach cisl in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { // 
	*replace $elast`g'_`cisl' = 5 if $elast`g'_`cisl' > 5
	*replace $elast`g'_`cisl' = -5 if $elast`g'_`cisl' < -5
	}
	
	* Percentage changes? 0.0..
	gen dpq_t01_w`g' = $elast`g'_1 * dpp_t01_w1 + $elast`g'_2 * dpp_t01_w2 + $elast`g'_3 * dpp_t01_w3 + $elast`g'_4 * dpp_t01_w4 + $elast`g'_5 * dpp_t01_w5 + $elast`g'_6 * dpp_t01_w6 + $elast`g'_7 * dpp_t01_w7 + $elast`g'_8 * dpp_t01_w8 + $elast`g'_9 * dpp_t01_w9 + $elast`g'_10 * dpp_t01_w10 + $elast`g'_11 * dpp_t01_w11 + $elast`g'_12 * dpp_t01_w12 + $elast`g'_13 * dpp_t01_w13 + $elast`g'_14 * dpp_t01_w14 + $elast`g'_15 * dpp_t01_w15  + IncElast_`g' * (growth_income / 100)
	gen dpq_t02_w`g' = $elast`g'_1 * dpp_t02_w1 + $elast`g'_2 * dpp_t02_w2 + $elast`g'_3 * dpp_t02_w3 + $elast`g'_4 * dpp_t02_w4 + $elast`g'_5 * dpp_t02_w5 + $elast`g'_6 * dpp_t02_w6 + $elast`g'_7 * dpp_t02_w7 + $elast`g'_8 * dpp_t02_w8 + $elast`g'_9 * dpp_t02_w9 + $elast`g'_10 * dpp_t02_w10 + $elast`g'_11 * dpp_t02_w11 + $elast`g'_12 * dpp_t02_w12 + $elast`g'_13 * dpp_t02_w13 + $elast`g'_14 * dpp_t02_w14 + $elast`g'_15 * dpp_t02_w15 + IncElast_`g' * (growth_income / 100)
	*gen dpq_t12_w`g' = $elast`g'_1 * dpp_t12_w1 + $elast`g'_2 * dpp_t12_w2 + $elast`g'_3 * dpp_t12_w3 + $elast`g'_4 * dpp_t12_w4 + $elast`g'_5 * dpp_t12_w5 + $elast`g'_6 * dpp_t12_w6 + $elast`g'_7 * dpp_t12_w7 + $elast`g'_8 * dpp_t12_w8 + $elast`g'_9 * dpp_t12_w9 + $elast`g'_10 * dpp_t12_w10 + $elast`g'_11 * dpp_t12_w11 + $elast`g'_12 * dpp_t12_w12 + $elast`g'_13 * dpp_t12_w13 + $elast`g'_14 * dpp_t12_w14 + $elast`g'_15 * dpp_t12_w15 + IncElast_`g' * (growth_income / 100)
	gen dpq_t12_w`g' = $elast`g'_1 * dpp_t12_w1 * b1 + $elast`g'_2 * dpp_t12_w2 * b2 + $elast`g'_3 * dpp_t12_w3 * b3 + $elast`g'_4 * dpp_t12_w4 * b4 + $elast`g'_5 * dpp_t12_w5 * b5 + $elast`g'_6 * dpp_t12_w6 * b6 + $elast`g'_7 * dpp_t12_w7 * b7 + $elast`g'_8 * dpp_t12_w8 * b8 + $elast`g'_9 * dpp_t12_w9 * b9 + $elast`g'_10 * dpp_t12_w10 * b10 + $elast`g'_11 * dpp_t12_w11 * b11 + $elast`g'_12 * dpp_t12_w12 * b12 + $elast`g'_13 * dpp_t12_w13 * b13 + $elast`g'_14 * dpp_t12_w14 * b14 + $elast`g'_15 * dpp_t12_w15 * b15 + IncElast_`g' * (growth_income / 100)
	}	



foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
	if "$QUAIDS" == "off" {
	gen dpq_t01_w`g' = -dpp_t01_w`g'
	gen dpq_t02_w`g' = -dpp_t02_w`g'
	gen dpq_t12_w`g' = -dpp_t12_w`g'
	}
	
	* Changes in Real expenditures/quantities
	gen dq_t01_w`g' = dpq_t01_w`g' * q_t0_w`g'
	gen dq_t02_w`g' = dpq_t02_w`g' * q_t0_w`g'
	
	* Quantities
	gen q_t02_w`g' = q_t0_w`g' + dq_t02_w`g'
	gen q_t01_w`g' = q_t0_w`g' + dq_t01_w`g'
	* t12 computations
	gen dq_t12_w`g' = dpq_t12_w`g' * q_t01_w`g'
	gen q_t12_w`g' = q_t01_w`g' + dq_t12_w`g'

	* Continuing the work only with t1 corresponding to the change from t0 to t1 and t2 corresponding to the cahnge from t1 to t2
	gen q_t1_w`g' = q_t01_w`g'
	gen q_t2_w`g' = q_t12_w`g'

	* Nominal expenditures
	gen e_t1_w`g' = q_t1_w`g' * p_t1_w`g'
	gen e_t2_w`g' = q_t2_w`g' * p_t2_w`g'	
	* Differences in nominal expenditures
	gen e_t01_w`g' = e_t1_w`g' - e_t0_w`g' 
	gen e_t12_w`g' = e_t2_w`g' - e_t1_w`g' 	
	
	* Presented results
	gen dx_t12_w`g' = e_t1_w`g' * (q_t2_w`g' - q_t1_w`g') / q_t1_w`g'
	
	* Government VAT revenues - 1 is the same as 2 - two equivalent methods
	* 1: E = (1 + 0.2) * Q === 0.2 * Q is the government revenue
	gen gr1_q_t0_w`g' = q_t0_w`g' * `31' / 100
	replace gr1_q_t0_w`g' = q_t0_w`g' * `30' / 100 if `g' == 1 | `g' == 5
	replace gr1_q_t0_w`g' = q_t0_w`g' * `32' / 100 if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	gen gr1_q_t1_w`g' = q_t1_w`g' * `2' / 100
	replace gr1_q_t1_w`g' = q_t1_w`g' * `1' / 100 if `g' == 1 | `g' == 5
	replace gr1_q_t1_w`g' = q_t1_w`g' * `28' / 100 if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	gen gr1_q_t2_w`g' = q_t2_w`g' * `4' / 100
	replace gr1_q_t2_w`g' = q_t2_w`g' * `3' / 100 if `g' == 1 | `g' == 5
	replace gr1_q_t2_w`g' = q_t2_w`g' * `29' / 100 if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	* 1: differences
	gen gr1_dq_t01_w`g' = gr1_q_t1_w`g' - gr1_q_t0_w`g'
	gen gr1_dq_t12_w`g' = gr1_q_t2_w`g' - gr1_q_t1_w`g'
	* 2: E = (1 + 0.2) * Q === (1 + 0.2 - 1) / (1 + 0.2) * E is the government revenue
	gen gr2_q_t0_w`g' = e_t0_w`g' * (100 + `31' - 100) / (100 + `31')
	replace gr2_q_t0_w`g' = e_t0_w`g' * (100 + `30' - 100) / (100 + `30') if `g' == 1 | `g' == 5
	replace gr2_q_t0_w`g' = e_t0_w`g' * (100 + `32' - 100) / (100 + `32') if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	gen gr2_q_t1_w`g' = e_t1_w`g' * (100 + `2' - 100) / (100 + `2') 
	replace gr2_q_t1_w`g' = e_t1_w`g' * (100 + `1' - 100) / (100 + `1') if `g' == 1 | `g' == 5
	replace gr2_q_t1_w`g' = e_t1_w`g' * (100 + `28' - 100) / (100 + `28') if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15
	gen gr2_q_t2_w`g' = e_t2_w`g' * (100 + `4' - 100) / (100 + `4') 
	replace gr2_q_t2_w`g' = e_t2_w`g' * (100 + `3' - 100) / (100 + `3')  if `g' == 1 | `g' == 5
	replace gr2_q_t2_w`g' = e_t2_w`g' * (100 + `29' - 100) / (100 + `29')  if `g' == 9 |  `g' == 10	|  `g' == 11	|  `g' == 12	|  `g' == 13	|  `g' == 14	|  `g' == 15

	* Total for the whole sample
	foreach var in gr1_q_t0_w`g' gr1_q_t1_w`g' dq_t01_w`g' dq_t12_w`g' gr1_dq_t12_w`g' gr1_dq_t01_w`g' e_t12_w`g' e_t01_w`g'  gr1_q_t2_w`g'  { 
	egen total_`var' = total(`var')
}
}


***********************************************************
****** Estimates of impact - totals across all groups *****
***********************************************************

foreach var in x_t12 { 
* Changes in Real expenditures - totals across groups
egen d`var' = rowtotal(d`var'_w1 d`var'_w2 d`var'_w3 d`var'_w4 d`var'_w5 d`var'_w6 d`var'_w7 d`var'_w8 d`var'_w9 d`var'_w10 d`var'_w11 d`var'_w12 d`var'_w13 d`var'_w14 d`var'_w15)
}

* Across all groups
* Individuals
* Totals for all groups
foreach var in q_t01 q_t02 q_t12 { 
* Total Real expenditures - totals across groups
egen t_`var' = rowtotal(`var'_w1 `var'_w2 `var'_w3 `var'_w4 `var'_w5 `var'_w6 `var'_w7 `var'_w8 `var'_w9 `var'_w10 `var'_w11 `var'_w12 `var'_w13 `var'_w14 `var'_w15)
}

foreach var in q_t01 q_t02 q_t12 x_t12 { 
* Changes in Real expenditures - totals across groups
egen td_`var' = rowtotal(d`var'_w1 d`var'_w2 d`var'_w3 d`var'_w4 d`var'_w5 d`var'_w6 d`var'_w7 d`var'_w8 d`var'_w9 d`var'_w10 d`var'_w11 d`var'_w12 d`var'_w13 d`var'_w14 d`var'_w15)
}
foreach var in q_t01 q_t02 q_t12 { 
* Percentage changes in Real expenditures - totals across groups
gen tdp_`var' = td_`var' / t_`var'
}

* Across all groups
* Government revenues
* Totals for all groups
foreach var in gr1_dq_t12 gr1_q_t0 gr1_q_t1 gr1_q_t2 gr2_q_t0 gr2_q_t1 gr2_q_t2 e_t0 e_t1 e_t2 q_t0 q_t1 q_t2 dq_t12 { 
* Government VAT revenues // Nominal and // Real expenditures
egen `var' = rowtotal(`var'_w1 `var'_w2 `var'_w3 `var'_w4 `var'_w5 `var'_w6 `var'_w7 `var'_w8 `var'_w9 `var'_w10 `var'_w11 `var'_w12 `var'_w13 `var'_w14 `var'_w15)
}

* Government revenues
* Shares of groups in the totals - government revenues
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
foreach var in gr1_q_t0 gr1_q_t1 gr1_q_t2 gr2_q_t0 gr2_q_t1 gr2_q_t2 e_t0 e_t1 e_t2 q_t0 q_t1 q_t2 dq_t12 { 
gen s`var'_w`g' = `var'_w`g' / `var' * 100
}
}

foreach var in se_t1 se_t2 { 
* Shares sum up to 100
egen `var' = rowtotal(`var'_w1 `var'_w2 `var'_w3 `var'_w4 `var'_w5 `var'_w6 `var'_w7 `var'_w8 `var'_w9 `var'_w10 `var'_w11 `var'_w12 `var'_w13 `var'_w14 `var'_w15)
}

****************************************************************
****** Estimates of impact - totals for the Czech Republic *****
****************************************************************
* Representatitiveness - pkoef
* 	for 2011 - I double the number of  7		dchodci (nepracujc) bez EA len in the sample under-represented - need to create duplicates according to pkoef
expand = 2 if (pkoef >= 1 & pkoef <= 2)

* Total for the whole sample
foreach var in  gr1_dq_t12 gr1_q_t0 gr1_q_t1 gr1_q_t2 gr2_q_t0 gr2_q_t1 gr2_q_t2 e_t0 e_t1 e_t2 q_t0 q_t1 q_t2 dq_t12  { 
egen total_`var' = total(`var')
}

* Total for the whole population
* esk republika mla k 30. ervnu 2012 10 512 208 obyvatel. http://www.czso.cz/csu/redakce.nsf/i/obyvatelstvo_lide
su osob zprav // --- after pkoef expansion: 3392 households with an average of 2.25517, in total 3392 * 2.25517 = 7649.5299 people. 10512208 CR / 7649.5299 Sample * 12 month = 16490.751 = coefficient to multiply all numbers
foreach var in gr1_dq_t12 gr1_q_t0 gr1_q_t1 gr1_q_t2 gr2_q_t0 gr2_q_t1 gr2_q_t2 e_t0 e_t1 e_t2 q_t0 q_t1 q_t2 dq_t12 { 
gen crtotal_`var' = total_`var' * 16490.751  / 1000000
}


* Total for the whole population
* esk republika mla k 30. ervnu 2012 10 512 208 obyvatel. http://www.czso.cz/csu/redakce.nsf/i/obyvatelstvo_lide
su osob zprav // --- after pkoef expansion: 3392 households with an average of 2.25517, in total 3392 * 2.25517 = 7649.5299 people. 10512208 CR / 7649.5299 Sample * 12 month = 16490.751 = coefficient to multiply all numbers
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
foreach var in gr1_q_t0_w`g' gr1_q_t1_w`g' dq_t01_w`g' dq_t12_w`g' gr1_dq_t12_w`g' gr1_dq_t01_w`g' e_t12_w`g' e_t01_w`g'  gr1_q_t2_w`g' { 
gen crtotal_`var' = total_`var' * 16490.751  / 1000000
}
}

* Perecentage changes for each group
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
gen dpq_t12_100_w`g' = 100 * dpq_t12_w`g'
gen dpq_t02_100_w`g' = 100 * dpq_t02_w`g'
gen dpp_t12_100_w`g' = 100 * dpp_t12_w`g'
}

* Perecentage changes for all groups
gen dpq_t01 = 0
gen dpq_t02 = 0
gen dpq_t12 = 0
* weighted averages 
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
foreach var in dpq_t01 dpq_t02 dpq_t12 {
   replace `var' = `var' + w`g' * `var'_w`g'
}
}
gen dpq_t12_100 = 100 * dpq_t12
gen dpq_t02_100 = 100 * dpq_t02


***********************************************************************************************
****** Estimates of impact - Excise duties - totals for the sample and the Czech Republic *****
***********************************************************************************************
* Total for the whole sample - Excise duties
foreach var in ed ed_fuel ed_beer ed_wine ed_spirit ed_cig ed_cigar ed_otob ed_alco ed_tob { 
egen total_`var' = total(`var')
}

* Excise duties - from total of the sample (and in months) to the total of the population (for the whole year)
* 7649.5299 people in the sample, which is .00072773 (0.07%) of the total population 10512208 CR. 10512208 / 7649.5299 = 1374.2293 to get it from sample to the population, and 1374.2293 * 12 = 16490.752 to get it from a month to a year
foreach var in  ed ed_fuel ed_beer ed_wine ed_spirit ed_cig ed_cigar ed_otob ed_alco ed_tob { 
gen crtotal_`var' = total_`var' * 16490.751 / 1000000
}
* All excise duties together
egen crtotal_ed2 = rowtotal(crtotal_ed_fuel crtotal_ed_beer crtotal_ed_wine crtotal_ed_spirit crtotal_ed_cig crtotal_ed_cigar crtotal_ed_otob crtotal_ed_alco crtotal_ed_tob)

* VAT and ED revenues
su crtotal_gr1_q_t2 crtotal_ed2

*************************************************
****** Income/Expenditure deciles/quantiles *****
*************************************************

* Recomputing Income Deciles - with the representative population
capture drop prij_kvantil* prij_decil* prijmy_oecd
* I want to use this:
* HH-level ukazatele pouvme decily vypotan z pjm na OECD jednotku (dleno potem osob v domcnosti podle OECD definice).
* Prmrn ist pjmy na spotebn jednotku v domcnosti jsou bn pouvny nap. v analzch OECD. Spotebn jednotky podle stupnice OECD maj vhy definovny takto: 
* prvn dospl v domcnosti = 1.0, kad dal dospl (osoba star 13 let) = 0.7, kad dt (13let nebo mlad) = 0.5.
* I want to make use of - SJ (Poet spotebnch jednotek - def. OECD (q)) which is in the HBS data,
*	souet za jednotliv osoby v domcnosti; ve spotebn jednotky pro jednotliv osoby zvis na sloen domcnosti a vku dt: 1,0 osoba v ele domcnosti,0,5	dti ve vku 0 a 13 let, 0,7 ostatn dti a osoby

* Income deciles variables for descriptive statistics
* pjmov kvantily
gen expm_oecd = expm/sj
gen prijmy_oecd = moninc/sj

* pjmov kvantily dle OECD - sj
_pctile prijmy_oecd, n(5) 
return list
gen prij_kvantil_oecd = 1 if prijmy_oecd <= r(r1)
replace prij_kvantil_oecd = 2 if prijmy_oecd > r(r1) & prijmy_oecd <= r(r2)
replace prij_kvantil_oecd = 3 if prijmy_oecd > r(r2) & prijmy_oecd <= r(r3)
replace prij_kvantil_oecd = 4 if prijmy_oecd > r(r3) & prijmy_oecd <= r(r4)
replace prij_kvantil_oecd = 5 if prijmy_oecd > r(r4)

* pjmov decily dle OECD - sj
_pctile prijmy_oecd, n(10) 
return list
gen prij_decil_oecd = 1 if prijmy_oecd <= r(r1)
replace prij_decil_oecd = 2 if prijmy_oecd > r(r1) & prijmy_oecd <= r(r2)
replace prij_decil_oecd = 3 if prijmy_oecd > r(r2) & prijmy_oecd <= r(r3)
replace prij_decil_oecd = 4 if prijmy_oecd > r(r3) & prijmy_oecd <= r(r4)
replace prij_decil_oecd = 5 if prijmy_oecd > r(r4) & prijmy_oecd <= r(r5)
replace prij_decil_oecd = 6 if prijmy_oecd > r(r5) & prijmy_oecd <= r(r6)
replace prij_decil_oecd = 7 if prijmy_oecd > r(r6) & prijmy_oecd <= r(r7)
replace prij_decil_oecd = 8 if prijmy_oecd > r(r7) & prijmy_oecd <= r(r8)
replace prij_decil_oecd = 9 if prijmy_oecd > r(r8) & prijmy_oecd <= r(r9)
replace prij_decil_oecd = 10 if prijmy_oecd > r(r9)

* Vdajov kvantily - monthly expenditures per household member
* vdajov kvantily dle OECD - sj
_pctile expm_oecd, n(5) 
return list
gen vyd_kvantil_oecd = 1 if expm_oecd <= r(r1)
replace vyd_kvantil_oecd = 2 if expm_oecd > r(r1) & expm_oecd <= r(r2)
replace vyd_kvantil_oecd = 3 if expm_oecd > r(r2) & expm_oecd <= r(r3)
replace vyd_kvantil_oecd = 4 if expm_oecd > r(r3) & expm_oecd <= r(r4)
replace vyd_kvantil_oecd = 5 if expm_oecd > r(r4)

* vdajov decily dle OECD
_pctile expm_oecd, n(10) 
return list
gen vyd_decil_oecd = 1 if expm_oecd <= r(r1)
replace vyd_decil_oecd = 2 if expm_oecd > r(r1) & expm_oecd <= r(r2)
replace vyd_decil_oecd = 3 if expm_oecd > r(r2) & expm_oecd <= r(r3)
replace vyd_decil_oecd = 4 if expm_oecd > r(r3) & expm_oecd <= r(r4)
replace vyd_decil_oecd = 5 if expm_oecd > r(r4) & expm_oecd <= r(r5)
replace vyd_decil_oecd = 6 if expm_oecd > r(r5) & expm_oecd <= r(r6)
replace vyd_decil_oecd = 7 if expm_oecd > r(r6) & expm_oecd <= r(r7)
replace vyd_decil_oecd = 8 if expm_oecd > r(r7) & expm_oecd <= r(r8)
replace vyd_decil_oecd = 9 if expm_oecd > r(r8) & expm_oecd <= r(r9)
replace vyd_decil_oecd = 10 if expm_oecd > r(r9)

capture mkdir $outputs/`27'

* Prijmy/Vydaje - ve zaplacench jednotlivch nepmch dan jako podl vdaj nebo istho pjmu domcnost (nebo-li prmrn nepm daov sazby a tedy podly promnnch ve dvou odrkch ve na vdajch nebo istm pjmu), (Podil_DPH_SD_nyni, Podil_DPH_SD_pote, Podil_DPH_SD_zmena)
foreach g in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 { 
gen gr1_q_e_t1_w`g' = 100 * gr1_q_t1_w`g' / expm
gen gr1_q_m_t1_w`g' = 100 * gr1_q_t1_w`g' / moninc
gen gr1_q_e_t2_w`g' = 100 * gr1_q_t2_w`g' / expm
gen gr1_q_m_t2_w`g' = 100 * gr1_q_t2_w`g' / moninc
gen gr1_q_t12_w`g'  = gr1_q_t2_w`g' - gr1_q_t1_w`g' 
gen gr1_q_e_t12_w`g' = 100 * gr1_q_t12_w`g' / expm
gen gr1_q_m_t12_w`g' = 100 * gr1_q_t12_w`g' / moninc
}
gen gr1_q_e_t1 = 100 * gr1_q_t1 / expm
gen gr1_q_m_t1 = 100 * gr1_q_t1 / moninc
gen gr1_q_e_t2 = 100 * gr1_q_t2 / expm
gen gr1_q_m_t2 = 100 * gr1_q_t2 / moninc
gen gr1_q_t12  = gr1_q_t2 - gr1_q_t1
gen gr1_q_e_t12 = 100 * gr1_q_t12 / expm
gen gr1_q_m_t12 = 100 * gr1_q_t12 / moninc
gen i = "|"


********** Tables
foreach decil in $dec {
* ve zaplacen dan z pidan hodnoty (kolik korun zaplat domcnost na DPH prostednictvm svch vdaj) 
* a v omezen me ve zaplacench spotebnch dan, uvalench na nsledujc zbo a sluby (kolik korun zaplat domcnost na spotebnch danch prostednictvm svch vdaj): pohonn hmoty, tabkov vrobky a alkoholick npoje, 
foreach var in gr1_q_t1 { 
tabout `decil' using "$outputs/`27'/Korun_DPH_SD_nyni_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane v korunach - nyni - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem)
}
foreach var in gr1_q_t2 { 
tabout `decil' using "$outputs/`27'/Korun_DPH_SD_pote_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane v korunach - pote - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem)
}
foreach var in gr1_q_t12 { 
tabout `decil' using "$outputs/`27'/Korun_DPH_SD_zmena_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane v korunach - zmena - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem)
}

* Vydaje - ve zaplacench jednotlivch nepmch dan jako podl vdaj nebo istho pjmu domcnost (nebo-li prmrn nepm daov sazby a tedy podly promnnch ve dvou odrkch ve na vdajch nebo istm pjmu), (Podil_DPH_SD_nyni, Podil_DPH_SD_pote, Podil_DPH_SD_zmena)
foreach var in gr1_q_e_t1 { 
tabout `decil' using "$outputs/`27'/Podil_vyjadu_DPH_SD_nyni_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil vydaju - nyni - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}
foreach var in gr1_q_e_t2 { 
tabout `decil' using "$outputs/`27'/Podil_vyjadu_DPH_SD_pote_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil vydaju - pote - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}
foreach var in gr1_q_e_t12 { 
tabout `decil' using "$outputs/`27'/Podil_vyjadu_DPH_SD_zmena_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil vydaju - zmena - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}

* Prijmy - ve zaplacench jednotlivch nepmch dan jako podl vdaj nebo istho pjmu domcnost (nebo-li prmrn nepm daov sazby a tedy podly promnnch ve dvou odrkch ve na vdajch nebo istm pjmu), (Podil_DPH_SD_nyni, Podil_DPH_SD_pote, Podil_DPH_SD_zmena)
foreach var in gr1_q_m_t1 { 
tabout `decil' using "$outputs/`27'/Podil_prijmu_DPH_SD_nyni_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil prijmu - nyni - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}
foreach var in gr1_q_m_t2 { 
tabout `decil' using "$outputs/`27'/Podil_prijmu_DPH_SD_pote_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil prijmu - pote - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}
foreach var in gr1_q_m_t12 { 
tabout `decil' using "$outputs/`27'/Podil_prijmu_DPH_SD_zmena_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Vyse zaplacene dane jako podil prijmu - zmena - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(2c)
}

* Table 6 Table 6. Changes in average expenditure shares after changes in VAT rates for 2013
* podl vdajovch skupin na celkovch zahrnutch vdajch ped a po zmn jednotlivch nepmch dan 
foreach var in se_t1 { 
tabout `decil' using "$outputs/`27'/Podil_skupin_nyni_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Podil vydajovych skupin - nyni - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem)
}
foreach var in se_t2 { 
tabout `decil' using "$outputs/`27'/Podil_skupin_pote_`27'_`var'.xls.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Podil vydajovych skupin - pote - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem)
}

* Table 8. Simulated average percentage changes in the quantity demanded in 2013 after changes in VAT rates from the 2012 baseline (%).
* zmna poptvanho mnostv jednotlivch vdajovch skupin pro kadou domcnost
* zmena realne poptavky
foreach var in dpq_t12_100  { 
tabout `decil' using "$outputs/`27'/Poptavane_mnozstvi_procentni_zmena_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Procentni zmena poptavaneho mnozstvi - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15)  total(Celkem) f(2c)
}
foreach var in dq_t12  { 
tabout `decil' using "$outputs/`27'/Poptavane_mnozstvi_korunova_zmena_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Zmena poptavaneho mnozstvi v korunach - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15)  total(Celkem)
}
*foreach var in crtotal_dpq_t12  { 
*tabout i using "$outputs/`27'/Agregatni_poptavane_mnozstvi_procentni_zmena_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Agregatni zmena poptavaneho mnozstvi v milionech korun - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(0c)
*}
foreach var in crtotal_dq_t12  { 
tabout i using "$outputs/`27'/Agregatni_poptavane_mnozstvi_korunova_zmena_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Agregatni zmena poptavaneho mnozstvi v milionech korun - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(0c)
}
* Prijmy rozpoctu ze spotrebnich dani
tabout i using "$outputs/`27'/Rozpocet_spotrebni_dane_nyni_`27'_`var'.xls", replace c(mean crtotal_ed_fuel mean crtotal_ed_beer mean crtotal_ed_wine mean crtotal_ed_spirit mean crtotal_ed_cig mean crtotal_ed_cigar mean crtotal_ed_otob mean crtotal_ed2) sum h2(Prijmy verejnych financi ze spotrebnich dani v milionech korun - nyni - `27') h3(|Benzin a nafta|Pivo|Vino|Ostatni alkohol|Cigarety|Doutniky|Ostatni tabak|Celkem)


* Zmna pjm veejnch financ
* Table 8. Effect of consumer demand response on revenues from changes in VAT rates from the 2012 baseline (billions Czech crowns) - drive - * Table 7. Effect of consumer demand response on revenues from changes in VAT rates
* pro stav ped zmnou, tak po zmn:	celkov pjmy veejnch financ z domcnostmi placen dan z pidan hodnoty a v omezen me pro spotebn dan (Rozpocet_nyni a Rozpocet_pote)
foreach var in crtotal_gr1_q_t1 {
tabout i using "$outputs/`27'/Rozpocet_DPH_nyni_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Prijmy verejnych financi z DPH v milionech korun - nyni - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15)
}
foreach var in crtotal_gr1_q_t2 {
tabout i using "$outputs/`27'/Rozpocet_DPH_pote_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Prijmy verejnych financi z DPH v milionech korun - pote - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15)
}
* pro zmny v nvaznosti na reformy nepmch dan: zmna pjm veejnch financ z domcnostmi placen dan z pidan hodnoty 
foreach var in crtotal_gr1_dq_t12 { 
tabout i using "$outputs/`27'/Rozpocet_DPH_zmena_`27'_`var'.xls", replace c(mean `var' mean `var'_w1 mean `var'_w2 mean `var'_w3 mean `var'_w4 mean `var'_w5 mean `var'_w6 mean `var'_w7 mean `var'_w8 mean `var'_w9 mean `var'_w10 mean `var'_w11 mean `var'_w12 mean `var'_w13 mean `var'_w14 mean `var'_w15) sum h2(Zmena prijmu verejnych financi z DPH v milionech korun - `27') h3(|Celkem|S1|S2|S3|S4|S5|S6|S7|S8|S9|S10|S11|S12|S13|S14|S15) total(Celkem) f(0c)
}
}
}
cd "$folder"
}
end

